From: Xueming Li <xuemingl@nvidia.com>
To: Wathsala Vithanage <wathsala.vithanage@arm.com>
Cc: <xuemingl@nvidia.com>, Dhruv Tripathi <dhruv.tripathi@arm.com>,
"dpdk stable" <stable@dpdk.org>
Subject: patch 'power: enable CPPC' has been queued to stable release 23.11.3
Date: Mon, 11 Nov 2024 14:27:15 +0800 [thread overview]
Message-ID: <20241111062847.216344-30-xuemingl@nvidia.com> (raw)
In-Reply-To: <20241111062847.216344-1-xuemingl@nvidia.com>
Hi,
FYI, your patch has been queued to stable release 23.11.3
Note it hasn't been pushed to http://dpdk.org/browse/dpdk-stable yet.
It will be pushed if I get no objections before 11/30/24. So please
shout if anyone has objections.
Also note that after the patch there's a diff of the upstream commit vs the
patch applied to the branch. This will indicate if there was any rebasing
needed to apply to the stable branch. If there were code changes for rebasing
(ie: not only metadata diffs), please double check that the rebase was
correctly done.
Queued patches are on a temporary branch at:
https://git.dpdk.org/dpdk-stable/log/?h=23.11-staging
This queued commit can be viewed at:
https://git.dpdk.org/dpdk-stable/commit/?h=23.11-staging&id=418efc7dd043b02b6666fe70b88613dd8984bb98
Thanks.
Xueming Li <xuemingl@nvidia.com>
---
From 418efc7dd043b02b6666fe70b88613dd8984bb98 Mon Sep 17 00:00:00 2001
From: Wathsala Vithanage <wathsala.vithanage@arm.com>
Date: Thu, 10 Oct 2024 14:17:36 +0000
Subject: [PATCH] power: enable CPPC
Cc: Xueming Li <xuemingl@nvidia.com>
[ upstream commit 35220c7cb3aff022b3a41919139496326ef6eecc ]
Power library already supports Linux CPPC driver,
but initialization was failing.
Enable its use in the drivers check,
and fix the name of the CPPC driver name.
Fixes: ef1cc88f1837 ("power: support cppc_cpufreq driver")
Signed-off-by: Wathsala Vithanage <wathsala.vithanage@arm.com>
Reviewed-by: Dhruv Tripathi <dhruv.tripathi@arm.com>
---
lib/power/power_cppc_cpufreq.c | 2 +-
lib/power/rte_power_pmd_mgmt.c | 11 ++++++-----
2 files changed, 7 insertions(+), 6 deletions(-)
diff --git a/lib/power/power_cppc_cpufreq.c b/lib/power/power_cppc_cpufreq.c
index bb70f6ae52..f2ba684c83 100644
--- a/lib/power/power_cppc_cpufreq.c
+++ b/lib/power/power_cppc_cpufreq.c
@@ -36,7 +36,7 @@
#define POWER_SYSFILE_SYS_MAX \
"/sys/devices/system/cpu/cpu%u/cpufreq/cpuinfo_max_freq"
-#define POWER_CPPC_DRIVER "cppc-cpufreq"
+#define POWER_CPPC_DRIVER "cppc_cpufreq"
#define BUS_FREQ 100000
enum power_state {
--
2.34.1
---
Diff of the applied patch vs upstream commit (please double-check if non-empty:
---
--- - 2024-11-11 14:23:06.652309809 +0800
+++ 0029-power-enable-CPPC.patch 2024-11-11 14:23:05.062192841 +0800
@@ -1 +1 @@
-From 35220c7cb3aff022b3a41919139496326ef6eecc Mon Sep 17 00:00:00 2001
+From 418efc7dd043b02b6666fe70b88613dd8984bb98 Mon Sep 17 00:00:00 2001
@@ -4,0 +5,3 @@
+Cc: Xueming Li <xuemingl@nvidia.com>
+
+[ upstream commit 35220c7cb3aff022b3a41919139496326ef6eecc ]
@@ -12 +14,0 @@
-Cc: stable@dpdk.org
@@ -22 +24 @@
-index 32aaacb948..e68b39b424 100644
+index bb70f6ae52..f2ba684c83 100644
@@ -35 +37 @@
-index b1c18a5f56..830a6c7a97 100644
+index 6f18ed0adf..20aa753c3a 100644
@@ -47 +49 @@
-- POWER_LOG(DEBUG, "Neither ACPI nor PSTATE modes are supported");
+- RTE_LOG(DEBUG, POWER, "Neither ACPI nor PSTATE modes are supported\n");
@@ -50 +52 @@
-+ POWER_LOG(DEBUG, "Only ACPI, PSTATE, AMD-PSTATE, or CPPC modes are supported");
++ RTE_LOG(DEBUG, POWER, "Only ACPI, PSTATE, AMD-PSTATE, or CPPC modes are supported\n");
@@ -59 +61 @@
-- POWER_LOG(DEBUG, "Neither ACPI nor PSTATE modes were initialized");
+- RTE_LOG(DEBUG, POWER, "Neither ACPI nor PSTATE modes were initialized\n");
@@ -61 +63 @@
-+ POWER_LOG(DEBUG, "Unable to initialize ACPI, PSTATE, AMD-PSTATE, or CPPC modes");
++ RTE_LOG(DEBUG, POWER, "Unable to initialize ACPI, PSTATE, AMD-PSTATE, or CPPC modes\n");
next prev parent reply other threads:[~2024-11-11 6:32 UTC|newest]
Thread overview: 128+ messages / expand[flat|nested] mbox.gz Atom feed top
2024-11-11 6:26 patch " Xueming Li
2024-11-11 6:26 ` patch 'bus/vdev: revert fix devargs in secondary process' " Xueming Li
2024-11-11 6:26 ` patch 'log: add a per line log helper' " Xueming Li
2024-11-12 9:02 ` David Marchand
2024-11-12 11:35 ` Xueming Li
2024-11-12 12:47 ` David Marchand
2024-11-12 13:56 ` Xueming Li
2024-11-12 14:09 ` David Marchand
2024-11-12 14:11 ` Xueming Li
2024-11-11 6:26 ` patch 'drivers: remove redundant newline from logs' " Xueming Li
2024-11-11 6:26 ` patch 'eal/x86: fix 32-bit write combining store' " Xueming Li
2024-11-11 6:26 ` patch 'test/event: fix schedule type' " Xueming Li
2024-11-11 6:26 ` patch 'test/event: fix target event queue' " Xueming Li
2024-11-11 6:26 ` patch 'examples/eventdev: fix queue crash with generic pipeline' " Xueming Li
2024-11-11 6:26 ` patch 'crypto/dpaa2_sec: fix memory leak' " Xueming Li
2024-11-11 6:26 ` patch 'common/dpaax/caamflib: fix PDCP SNOW-ZUC watchdog' " Xueming Li
2024-11-11 6:26 ` patch 'dev: fix callback lookup when unregistering device' " Xueming Li
2024-11-11 6:26 ` patch 'crypto/scheduler: fix session size computation' " Xueming Li
2024-11-11 6:26 ` patch 'examples/ipsec-secgw: fix dequeue count from cryptodev' " Xueming Li
2024-11-11 6:26 ` patch 'bpf: fix free function mismatch if convert fails' " Xueming Li
2024-11-11 6:27 ` patch 'baseband/la12xx: fix use after free in modem config' " Xueming Li
2024-11-11 6:27 ` patch 'common/qat: fix use after free in device probe' " Xueming Li
2024-11-11 6:27 ` patch 'common/idpf: fix use after free in mailbox init' " Xueming Li
2024-11-11 6:27 ` patch 'crypto/bcmfs: fix free function mismatch' " Xueming Li
2024-11-11 6:27 ` patch 'dma/idxd: fix free function mismatch in device probe' " Xueming Li
2024-11-11 6:27 ` patch 'event/cnxk: fix free function mismatch in port config' " Xueming Li
2024-11-11 6:27 ` patch 'net/cnxk: fix use after free in mempool create' " Xueming Li
2024-11-11 6:27 ` patch 'net/cpfl: fix invalid free in JSON parser' " Xueming Li
2024-11-11 6:27 ` patch 'net/e1000: fix use after free in filter flush' " Xueming Li
2024-11-11 6:27 ` patch 'net/nfp: fix double free in flow destroy' " Xueming Li
2024-11-11 6:27 ` patch 'net/sfc: fix use after free in debug logs' " Xueming Li
2024-11-11 6:27 ` patch 'raw/ifpga/base: fix use after free' " Xueming Li
2024-11-11 6:27 ` patch 'raw/ifpga: fix free function mismatch in interrupt config' " Xueming Li
2024-11-11 6:27 ` patch 'examples/vhost: fix free function mismatch' " Xueming Li
2024-11-11 6:27 ` patch 'net/nfb: fix use after free' " Xueming Li
2024-11-11 6:27 ` Xueming Li [this message]
2024-11-11 6:27 ` patch 'fib6: add runtime checks in AVX512 lookup' " Xueming Li
2024-11-11 6:27 ` patch 'pcapng: fix handling of chained mbufs' " Xueming Li
2024-11-11 6:27 ` patch 'app/dumpcap: fix handling of jumbo frames' " Xueming Li
2024-11-11 6:27 ` patch 'ml/cnxk: fix handling of TVM model I/O' " Xueming Li
2024-11-11 6:27 ` patch 'net/cnxk: fix Rx timestamp handling for VF' " Xueming Li
2024-11-11 6:27 ` patch 'net/cnxk: fix Rx offloads to handle timestamp' " Xueming Li
2024-11-11 6:27 ` patch 'event/cnxk: fix Rx timestamp handling' " Xueming Li
2024-11-11 6:27 ` patch 'common/cnxk: fix MAC address change with active VF' " Xueming Li
2024-11-11 6:27 ` patch 'common/cnxk: fix inline CTX write' " Xueming Li
2024-11-11 6:27 ` patch 'common/cnxk: fix CPT HW word size for outbound SA' " Xueming Li
2024-11-11 6:27 ` patch 'net/cnxk: fix OOP handling for inbound packets' " Xueming Li
2024-11-11 6:27 ` patch 'event/cnxk: fix OOP handling in event mode' " Xueming Li
2024-11-11 6:27 ` patch 'common/cnxk: fix base log level' " Xueming Li
2024-11-11 6:27 ` patch 'common/cnxk: fix IRQ reconfiguration' " Xueming Li
2024-11-11 6:27 ` patch 'baseband/acc: fix access to deallocated mem' " Xueming Li
2024-11-11 6:27 ` patch 'baseband/acc: fix soft output bypass RM' " Xueming Li
2024-11-11 6:27 ` patch 'vhost: fix offset while mapping log base address' " Xueming Li
2024-11-11 6:27 ` patch 'vdpa: update used flags in used ring relay' " Xueming Li
2024-11-11 6:27 ` patch 'vdpa/nfp: fix hardware initialization' " Xueming Li
2024-11-11 6:27 ` patch 'vdpa/nfp: fix reconfiguration' " Xueming Li
2024-11-11 6:27 ` patch 'net/virtio-user: reset used index counter' " Xueming Li
2024-11-11 6:27 ` patch 'vhost: restrict set max queue pair API to VDUSE' " Xueming Li
2024-11-11 6:27 ` patch 'fib: fix AVX512 lookup' " Xueming Li
2024-11-11 6:27 ` patch 'net/e1000: fix link status crash in secondary process' " Xueming Li
2024-11-11 6:27 ` patch 'net/cpfl: add checks for flow action types' " Xueming Li
2024-11-11 6:27 ` patch 'net/iavf: fix crash when link is unstable' " Xueming Li
2024-11-11 6:27 ` patch 'net/cpfl: fix parsing protocol ID mask field' " Xueming Li
2024-11-11 6:27 ` patch 'net/ice/base: fix link speed for 200G' " Xueming Li
2024-11-11 6:27 ` patch 'net/ice/base: fix iteration of TLVs in Preserved Fields Area' " Xueming Li
2024-11-11 6:27 ` patch 'net/ixgbe/base: fix unchecked return value' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e/base: fix setting flags in init function' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e/base: fix misleading debug logs and comments' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e/base: add missing X710TL device check' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e/base: fix blinking X722 with X557 PHY' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e/base: fix DDP loading with reserved track ID' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e/base: fix repeated register dumps' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e/base: fix unchecked return value' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e/base: fix loop bounds' " Xueming Li
2024-11-11 6:27 ` patch 'net/iavf: delay VF reset command' " Xueming Li
2024-11-11 6:27 ` patch 'net/i40e: fix AVX-512 pointer copy on 32-bit' " Xueming Li
2024-11-11 6:27 ` patch 'net/ice: " Xueming Li
2024-11-11 6:27 ` patch 'net/iavf: " Xueming Li
2024-11-11 6:27 ` patch 'common/idpf: " Xueming Li
2024-11-11 6:27 ` patch 'net/gve: fix queue setup and stop' " Xueming Li
2024-11-11 6:28 ` patch 'net/gve: fix Tx for chained mbuf' " Xueming Li
2024-11-11 6:28 ` patch 'net/tap: avoid memcpy with null argument' " Xueming Li
2024-11-11 6:28 ` patch 'app/testpmd: remove unnecessary cast' " Xueming Li
2024-11-11 6:28 ` patch 'net/pcap: set live interface as non-blocking' " Xueming Li
2024-11-11 6:28 ` patch 'net/mana: support rdma-core via pkg-config' " Xueming Li
2024-11-11 6:28 ` patch 'net/ena: revert redefining memcpy' " Xueming Li
2024-11-11 6:28 ` patch 'net/hns3: remove some basic address dump' " Xueming Li
2024-11-11 6:28 ` patch 'net/hns3: fix dump counter of registers' " Xueming Li
2024-11-11 6:28 ` patch 'ethdev: fix overflow in descriptor count' " Xueming Li
2024-11-11 6:28 ` patch 'bus/dpaa: fix PFDRs leaks due to FQRNIs' " Xueming Li
2024-11-11 6:28 ` patch 'net/dpaa: fix typecasting channel ID' " Xueming Li
2024-11-11 6:28 ` patch 'bus/dpaa: fix VSP for 1G fm1-mac9 and 10' " Xueming Li
2024-11-11 6:28 ` patch 'bus/dpaa: fix the fman details status' " Xueming Li
2024-11-11 6:28 ` patch 'net/dpaa: fix reallocate mbuf handling' " Xueming Li
2024-11-11 6:28 ` patch 'net/gve: fix mbuf allocation memory leak for DQ Rx' " Xueming Li
2024-11-11 6:28 ` patch 'net/gve: always attempt Rx refill on DQ' " Xueming Li
2024-11-11 6:28 ` patch 'net/nfp: fix type declaration of some variables' " Xueming Li
2024-11-11 6:28 ` patch 'net/nfp: fix representor port link status update' " Xueming Li
2024-11-11 6:28 ` patch 'net/gve: fix refill logic causing memory corruption' " Xueming Li
2024-11-11 6:28 ` patch 'net/gve: add IO memory barriers before reading descriptors' " Xueming Li
2024-11-11 6:28 ` patch 'net/memif: fix buffer overflow in zero copy Rx' " Xueming Li
2024-11-11 6:28 ` patch 'net/tap: restrict maximum number of MP FDs' " Xueming Li
2024-11-11 6:28 ` patch 'ethdev: verify queue ID in Tx done cleanup' " Xueming Li
2024-11-11 6:28 ` patch 'net/hns3: verify reset type from firmware' " Xueming Li
2024-11-11 6:28 ` patch 'net/nfp: fix link change return value' " Xueming Li
2024-11-11 6:28 ` patch 'net/nfp: fix pause frame setting check' " Xueming Li
2024-11-11 6:28 ` patch 'net/pcap: fix blocking Rx' " Xueming Li
2024-11-11 6:28 ` patch 'net/ice/base: add bounds check' " Xueming Li
2024-11-11 6:28 ` patch 'net/ice/base: fix VLAN replay after reset' " Xueming Li
2024-11-11 6:28 ` patch 'net/iavf: preserve MAC address with i40e PF Linux driver' " Xueming Li
2024-11-11 6:28 ` patch 'net/mlx5: workaround list management of Rx queue control' " Xueming Li
2024-11-11 6:28 ` patch 'net/mlx5/hws: fix flex item as tunnel header' " Xueming Li
2024-11-11 6:28 ` patch 'net/mlx5: add flex item query for tunnel mode' " Xueming Li
2024-11-11 6:28 ` patch 'net/mlx5: fix flex item " Xueming Li
2024-11-11 6:28 ` patch 'net/mlx5: fix number of supported flex parsers' " Xueming Li
2024-11-11 6:28 ` patch 'app/testpmd: remove flex item init command leftover' " Xueming Li
2024-11-11 6:28 ` patch 'net/mlx5: fix next protocol validation after flex item' " Xueming Li
2024-11-11 6:28 ` patch 'net/mlx5: fix non full word sample fields in " Xueming Li
2024-11-11 6:28 ` patch 'net/mlx5: fix flex item header length field translation' " Xueming Li
2024-11-11 6:28 ` patch 'build: remove version check on compiler links function' " Xueming Li
2024-11-11 6:28 ` patch 'hash: fix thash LFSR initialization' " Xueming Li
2024-11-11 6:28 ` patch 'net/nfp: notify flower firmware about PF speed' " Xueming Li
2024-11-11 6:28 ` patch 'net/nfp: do not set IPv6 flag in transport mode' " Xueming Li
2024-11-11 6:28 ` patch 'dmadev: fix potential null pointer access' " Xueming Li
2024-11-11 6:28 ` patch 'net/gve/base: fix build with Fedora Rawhide' " Xueming Li
2024-11-11 6:28 ` patch 'power: fix mapped lcore ID' " Xueming Li
2024-11-11 6:28 ` patch 'net/ionic: fix build with Fedora Rawhide' " Xueming Li
2024-11-11 6:28 ` patch '' " Xueming Li
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20241111062847.216344-30-xuemingl@nvidia.com \
--to=xuemingl@nvidia.com \
--cc=dhruv.tripathi@arm.com \
--cc=stable@dpdk.org \
--cc=wathsala.vithanage@arm.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).
diff --git a/lib/power/rte_power_pmd_mgmt.c b/lib/power/rte_power_pmd_mgmt.c
index 6f18ed0adf..20aa753c3a 100644
--- a/lib/power/rte_power_pmd_mgmt.c
+++ b/lib/power/rte_power_pmd_mgmt.c
@@ -419,11 +419,12 @@ check_scale(unsigned int lcore)
{
enum power_management_env env;
/* only PSTATE and ACPI modes are supported */
if (!rte_power_check_env_supported(PM_ENV_ACPI_CPUFREQ) &&
!rte_power_check_env_supported(PM_ENV_PSTATE_CPUFREQ) &&
- !rte_power_check_env_supported(PM_ENV_AMD_PSTATE_CPUFREQ)) {
- RTE_LOG(DEBUG, POWER, "Neither ACPI nor PSTATE modes are supported\n");
+ !rte_power_check_env_supported(PM_ENV_AMD_PSTATE_CPUFREQ) &&
+ !rte_power_check_env_supported(PM_ENV_CPPC_CPUFREQ)) {
+ RTE_LOG(DEBUG, POWER, "Only ACPI, PSTATE, AMD-PSTATE, or CPPC modes are supported\n");
return -ENOTSUP;
}
/* ensure we could initialize the power library */
@@ -433,8 +434,8 @@ check_scale(unsigned int lcore)
/* ensure we initialized the correct env */
env = rte_power_get_env();
if (env != PM_ENV_ACPI_CPUFREQ && env != PM_ENV_PSTATE_CPUFREQ &&
- env != PM_ENV_AMD_PSTATE_CPUFREQ) {
- RTE_LOG(DEBUG, POWER, "Neither ACPI nor PSTATE modes were initialized\n");
+ env != PM_ENV_AMD_PSTATE_CPUFREQ && env != PM_ENV_CPPC_CPUFREQ) {
+ RTE_LOG(DEBUG, POWER, "Unable to initialize ACPI, PSTATE, AMD-PSTATE, or CPPC modes\n");
return -ENOTSUP;
}
@@ -419,11 +419,12 @@ check_scale(unsigned int lcore)
{
enum power_management_env env;
- /* only PSTATE and ACPI modes are supported */
+ /* only PSTATE, AMD-PSTATE, ACPI and CPPC modes are supported */
if (!rte_power_check_env_supported(PM_ENV_ACPI_CPUFREQ) &&
!rte_power_check_env_supported(PM_ENV_PSTATE_CPUFREQ) &&